@@ -100,25 +100,41 @@ def loaddata(marketlist=None, refresh=False):
         OPEN[DATE_ordinal_IDX,j], HIGH[DATE_ordinal_IDX,j], LOW[DATE_ordinal_IDX,j], CLOSE[DATE_ordinal_IDX,j], VOL[DATE_ordinal_IDX,j], E[DATE_ordinal_IDX,j] = data[DATES_idx,1], data[DATES_idx,2], data[DATES_idx,3], data[DATES_idx,4], data[DATES_idx,5], data[DATES_idx,6]
         DATE_global=map(sum, zip(DATE_global,DATE_ordinal_IDX))
 
-    CLOSE=CLOSE[~np.isnan(CLOSE).all(axis=1)]
+
+
+    #does this eliminate the entire row if there is any nan?
+    ixDel= np.isnan(OPEN).all(axis=1) | np.isnan(CLOSE).all(axis=1) | np.isnan(LOW).all(axis=1) | np.isnan(HIGH).all(axis=1) | np.isnan(VOL).all(axis=1) | np.isnan(E).all(axis=1)
+
+    OPEN[ixDel]=np.nan
+    CLOSE[ixDel]=np.nan
+    HIGH[ixDel]=np.nan
+    LOW[ixDel]=np.nan
+
+
+    ixKeep=~ixDel
+
+    DATES_out=[DATE_Large[i] for i in range(len(OrdinalRange)) if ixKeep[i]==True]
+    CLOSE=CLOSE[ixKeep]
+    OPEN=OPEN[ixKeep]
+    HIGH=HIGH[ixKeep]
+    LOW=LOW[ixKeep]
+    VOL=VOL[ixKeep]
+    E=E[ixKeep]
+
+
+    VOL[np.isnan(VOL)]=0
+    E[np.isnan(E)]=0
 
     CLOSE=fillnans(CLOSE)
 
-    OPEN=OPEN[~np.isnan(OPEN).all(axis=1)]
-    LOW=LOW[~np.isnan(LOW).all(axis=1)]
-    HIGH=HIGH[~np.isnan(HIGH).all(axis=1)]
-    VOL=VOL[~np.isnan(VOL).all(axis=1)]
-    E=E[~np.isnan(E).all(axis=1)]
     OPEN, HIGH, LOW = fillwith(OPEN,CLOSE), fillwith(HIGH,CLOSE), fillwith(LOW,CLOSE)
 
-    E[np.isnan(E)]=0
 
-    finalDates=map(bool,DATE_global)
-    DATES_out=[DATE_Large[i] for i in range(len(OrdinalRange)) if finalDates[i]==True]
 
     print '\b Done! \n',
     sys.stdout.flush()
 
+
     return CLOSE,OPEN,HIGH,LOW,VOL,E,fieldNames, DATES_out
 
 
@@ -165,22 +181,25 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
 
     # get boolean index of futures
 
-    futuresIx=map(lambda string:bool(re.match("F_",string)),settings['markets'])
+    futuresIx=np.array(map(lambda string:bool(re.match("F_",string)),settings['markets']))
 
 
     #Load markets and pass data to data variables
-#    global CLOSE,OPEN,HIGH,LOW,VOL,R,fieldNames,DATE
+
     CLOSE,OPEN,HIGH,LOW,VOL,R,fieldNames,DATE=loaddata( settings['markets'],reloadData)
     SLIPPAGE = (HIGH - LOW) *  settings['slippage']
 
     errorlog=[]
     nMarkets=len( settings['markets'])
     nDays=len(DATE)
+
     Rix= R>0
 
+
+
     equity=np.zeros((nDays,nMarkets))
     exposure=np.zeros((nDays+2,nMarkets))
-    returns=CLOSE-OPEN
+    returns=fillnans(CLOSE-OPEN)
     gaps=OPEN[1:,:]-CLOSE[0:-1,:]
     gaps=np.insert(gaps,0,np.zeros((1,nMarkets))*np.nan,axis=0)
 
@@ -232,14 +251,23 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
 
      # Morning
 
-        equity[t,:]=equity[t-1,:]+newGap * np.invert(Rix[t,:])
+        equity[t,:]=equity[t-1,:]+newGap * np.invert(Rix[t,:].copy())
 
         # Dynamic contract Rolls
+        if DATE[t]==DATE[700+504+447]:
+            pass
+        elif DATE[t]=='20040922':
+            pass
+
+
         if np.any(Rix[t,:]):
-            CLOSE[0:t,Rix[t,:]] = CLOSE[0:t,Rix[t,:]] + np.tile( OPEN[t,Rix[t,:]]-CLOSE[t-1,Rix[t,:]],(t,1) )
-            OPEN[0:t,Rix[t,:]]  = OPEN[0:t,Rix[t,:]]  + np.tile(OPEN[t,Rix[t,:]]-CLOSE[t-1,Rix[t,:]],(t,1))
-            HIGH[0:t,Rix[t,:]] = HIGH[0:t,Rix[t,:]] + np.tile(OPEN[t,Rix[t,:]]-CLOSE[t-1,Rix[t,:]],(t,1))
-            LOW[0:t,Rix[t,:]]   = LOW[0:t,Rix[t,:]]   + np.tile(OPEN[t,Rix[t,:]]-CLOSE[t-1,Rix[t,:]],(t,1))
+            delta=np.tile( OPEN[t,Rix[t,:]]-CLOSE[t-1,Rix[t,:]],(t,1) )
+
+            CLOSE[0:t,Rix[t,:]] = CLOSE[0:t,Rix[t,:]].copy() + delta.copy()
+            OPEN[0:t,Rix[t,:]]  = OPEN[0:t,Rix[t,:]].copy()  + delta.copy()
+            HIGH[0:t,Rix[t,:]] = HIGH[0:t,Rix[t,:]].copy() + delta.copy()
+            LOW[0:t,Rix[t,:]]   = LOW[0:t,Rix[t,:]].copy()   + delta.copy()
+
 
         cash=settings['budget']+np.sum(equity[t,:])
 
@@ -285,6 +313,7 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
             deltaP =  dP.copy()
 
     # market participation check
+
         V = VOL[t,:].copy()
         V[np.isnan(V)] = 0
         V[futuresIx]=10**8
@@ -305,7 +334,7 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
 
            #python returns the value up to but not including the end of the slice (hence the t+1 or +2 in the case of exposure)
             if filePathFlag is True:
-                position, settings = TSmodule.myTradingSystem(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:], VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
+                position, settings = TSmodule.myTradingSystem(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:].copy(), VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
             else:
                 position, settings = TSobject.myTradingSystem(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:], VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
         except:
@@ -603,22 +632,21 @@ def fillnans(inArr):
     nanPos= np.where(np.isnan(inArr))
     nanRow=nanPos[0]
     nanCol=nanPos[1]
-
+    myArr=inArr.copy()
     for i in range(len(nanRow)):
         if nanRow[i] >0:
-            inArr[nanRow[i],nanCol[i]]=inArr[nanRow[i]-1,nanCol[i]]
-    return inArr
+            myArr[nanRow[i],nanCol[i]]=myArr[nanRow[i]-1,nanCol[i]]
+    return myArr
 
 def fillwith(field, lookup):
 
-    out = field
-    nanPos= np.where(np.isnan(out[2:,:]));
+    out = field.copy()
+    nanPos= np.where(np.isnan(out[:,:]))
     nanRow=nanPos[0]
     nanCol=nanPos[1]
 
     for i in range(len(nanRow)):
-        if nanRow[i] > 0:
-            out[nanRow[i],nanCol[i]] = lookup[nanRow[i]-1,nanCol[i]];
+        out[nanRow[i],nanCol[i]] = lookup[nanRow[i]-1,nanCol[i]];
 
     return out
 
